@@ -1,10 +1,10 @@
 import abc
-import copy
 
-from astropy.io import fits
+from sunraster.extern.meta import Meta
 
 __all__ = ["Meta", "RemoteSensorMetaABC", "SlitSpectrographMetaABC"]
 
+
 class MetaABC(abc.ABCMeta):
     @abc.abstractproperty
     def detector(self):
@@ -20,21 +20,23 @@ class MetaABC(abc.ABCMeta):
 
     @abc.abstractproperty
     def processing_level(self):
-        """The level to which the data has been processed."""
-        pass
+        """
+        The level to which the data has been processed.
+        """
 
     @abc.abstractproperty
     def observer_location(self):
-        """Coordinate of observatory location based on header info."""
-        pass
+        """
+        Coordinate of observatory location based on header info.
+        """
 
     @abc.abstractproperty
     def date_reference(self):
-        """The base time from which time axis values are measured.
+        """
+        The base time from which time axis values are measured.
 
         Often the same or very similar to date_start.
         """
-        pass
 
     @abc.abstractproperty
     def date_start(self):
@@ -46,25 +48,29 @@ class MetaABC(abc.ABCMeta):
 
     @abc.abstractproperty
     def version(self):
-        """The data version."""
-        pass
+        """
+        The data version.
+        """
 
 
 class RemoteSensorMetaABC(MetaABC):
     @abc.abstractproperty
     def rsun_meters(self):
-        """Solar radius in units of length."""
-        pass
+        """
+        Solar radius in units of length.
+        """
 
     @abc.abstractproperty
     def rsun_angular(self):
-        """Solar radius in angular units as seen from observatory."""
-        pass
+        """
+        Solar radius in angular units as seen from observatory.
+        """
 
     @abc.abstractproperty
     def distance_to_sun(self):
-        """Distance to Sun center from observatory."""
-        pass
+        """
+        Distance to Sun center from observatory.
+        """
 
 
 class SlitSpectrographMetaABC(RemoteSensorMetaABC):
@@ -74,21 +80,14 @@ class SlitSpectrographMetaABC(RemoteSensorMetaABC):
 
     @abc.abstractproperty
     def observing_mode_id(self):
-        """Unique identifier for the observing mode. Often referred to as OBS ID."""
-        pass
+        """
+        Unique identifier for the observing mode.
+
+        Often referred to as OBS ID.
+        """
 
     @abc.abstractproperty
     def observer_radial_velocity(self):
-        """Velocity of observatory in direction of source."""
-        pass
-
-
-class Meta(dict):
-    def __init__(self, header, comments=None):
-        super().__init__(header)
-        self.original_header = header
-        if comments is None:
-            comments = {}
-        else:
-            comments = dict(comments)
-        self.comments = comments
+        """
+        Velocity of observatory in direction of source.
+        """
